#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resourcet
version:              1.2.6
visibility:           public
id:                   resourcet-1.2.6-7T9Z3tkbFLZEgcLiw5udFH
key:                  resourcet-1.2.6-7T9Z3tkbFLZEgcLiw5udFH
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.

category:             Data, Conduit
abi:                  267daf768cffb0f8a3b7f4d41fba4293
exposed:              True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource

import-dirs:          /usr/lib/ghc-9.6.6/site-local/resourcet-1.2.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/resourcet-1.2.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/resourcet-1.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resourcet
hs-libraries:         HSresourcet-1.2.6-7T9Z3tkbFLZEgcLiw5udFH
depends:
    base-4.18.2.1 containers-0.6.7 exceptions-0.10.7 mtl-2.3.1
    primitive-0.9.1.0-E1xWGIz4UCzCm0xql5yb2P transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html:         /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

